@@ -29,7 +29,7 @@ def auth_required(function):
         """
         try:
             print("inside of try")
-            token = request.json['token']
+            token = request.headers['token']
             user = User.query.filter_by(token=token).first()
             if user is not None:
                 return function(token, *args, **kwargs) if authorized(user, token) else "Auth failed, maybe you token is expired, try login again"
